==> spirit_hub-0.0.1.0.tar.gz: spirit_hub-0.0.1.0/app/controllers/spirit_hub/to_categorizes_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class ToCategorizesController < ApplicationController
    before_action :find_models, only: %i[index sort]

    include Datatablable

    def index
      skip_authorization
      skip_policy_scope

      respond_to(&:html)
    end

    def sort
      skip_authorization
      skip_policy_scope

      render partial: 'spirit_hub/to_categorizes/table'
    end

    def categorize_form
      skip_authorization
      skip_policy_scope

      ids = params[:ids].split(',')

      @models = Tagset.where(:id.in => ids).to_a
      @tagsets = Tagset.where(type: 'directory').order_by(updated_at: :desc).limit(5)

      render turbo_stream: [
        turbo_stream.update(:modal, partial: 'spirit_hub/common/categorize_form')
      ]
    end

    def add_to_directory # rubocop:disable Metrics/AbcSize,Metrics/CyclomaticComplexity,Metrics/PerceivedComplexity
      skip_authorization
      skip_policy_scope

      ids = params[:ids].split(',')

      @models = Tagset.where(:id.in => ids).to_a

      if params[:tagset_id].present?
        if (tagset = Tagset.find(params[:tagset_id]))
          @models.each do |model|
            tagset.update(tagset_ids: tagset.tagset_ids.to_a + [model.id])
          end
        elsif (completeness = Completeness.find(params[:tagset_id]))
          @models.each do |model|
            completeness.tagset.update(tagset_ids: completeness.tagset.tagset_ids.to_a + [model.id])
            completeness.update(object_ids: completeness.object_ids.to_a + [model.id])
          end
        end

        @models.each do |model|
          if (new_state = model.cycle&.states&.find_by(key: :share))
            model.update(state: new_state)
          end
        end
      end

      flash.now[:notice] = 'Documents classés'

      render turbo_stream: [
        *ids.map { |id| turbo_stream.remove("tagset_#{id}") },
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
        turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -ids.length })
      ]
    end

    def add_doc # rubocop:disable Metrics/AbcSize
      skip_authorization
      skip_policy_scope

      file = params[:file]
      doc = Doc.create(responsible: @user.id, title: file.original_filename)
      doc.blob = file.read
      doc.update(type: 'file')
      tagset_doc = Tagset.create!(doc_ids: [doc.id], responsible: @user.id, type: 'document', title: file.original_filename, labels: ['hubdoc'])

      if params[:tagset_id].present?
        if (tagset = Tagset.find(params[:tagset_id]))
          tagset.update(tagset_ids: tagset.tagset_ids.to_a + [tagset_doc.id])
        elsif (completeness = Completeness.find(params[:tagset_id]))
          completeness.tagset.update(tagset_ids: completeness.tagset.tagset_ids.to_a + [tagset_doc.id])
          completeness.update(object_ids: completeness.object_ids.to_a + [tagset_doc.id])
        end
        if (new_state = tagset_doc.cycle.states.find_by(key: :share))
          tagset_doc.update(state: new_state)
        end
      end

      flash.now[:notice] = 'Documents ajouté'
      render turbo_stream: [
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
      ]
    end

    private

    def default_columns
      {
        type: { label: 'Type', sortable: true },
        cleaned_main_key: { label: 'Libellé', sortable: true },
        doc_file_size: { label: 'Poids', sortable: true },
        updated_at: { label: 'Dernière modification', sortable: true },
        last_current_user_name: { label: 'Provenance', sortable: true },
        informed: { label: 'Partagé', sortable: false },
        current_state: { label: 'Statut', sortable: true }
      }.freeze
    end

    def find_models
      scope = Tagset.where(:parent_tagset_ids.in => [nil, []], type: 'document', responsible: @user.id)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end

==> spirit_hub-0.0.1.5.tar.gz: spirit_hub-0.0.1.5/app/controllers/spirit_hub/to_categorizes_controller.rb <==
# frozen_string_literal: true

module SpiritHub
  class ToCategorizesController < ApplicationController
    before_action :find_models, only: %i[index sort]

    include Datatablable

    def index
      skip_authorization
      skip_policy_scope

      respond_to(&:html)
    end

    def sort
      skip_authorization
      skip_policy_scope

      render partial: 'spirit_hub/to_categorizes/table'
    end

    def categorize_form
      skip_authorization
      skip_policy_scope

      ids = params[:ids].split(',')

      @models = Tagset.where(:id.in => ids).to_a
      @tagsets = Tagset.where(type: 'directory').order_by(updated_at: :desc).limit(5)

      render turbo_stream: [
        turbo_stream.update(:modal, partial: 'spirit_hub/common/categorize_form')
      ]
    end

    def add_to_directory
      skip_authorization
      skip_policy_scope

      ids = params[:ids].split(',')

      @models = Tagset.where(:id.in => ids).to_a

      @models.each do |model|
        model.add_tagset_doc_to_object(params[:tagset_id])
      end

      flash.now[:notice] = 'Documents classés'

      render turbo_stream: [
        *ids.map { |id| turbo_stream.remove("tagset_#{id}") },
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages'),
        turbo_stream.custom_action(:change_counter, target: :end_index, attributes: { amount: -ids.length })
      ]
    end

    def add_doc # rubocop:disable Metrics/AbcSize
      skip_authorization
      skip_policy_scope

      file = params[:file]
      doc = Doc.create(responsible: @user.id, title: file.original_filename)
      doc.blob = file.read
      doc.update(type: 'file')
      tagset_doc = Tagset.create!(doc_ids: [doc.id], responsible: @user.id, type: 'document', title: file.original_filename, labels: ['hubdoc'])

      if params[:tagset_id].present?
        if (tagset = Tagset.find(params[:tagset_id]))
          tagset.update(tagset_ids: tagset.tagset_ids.to_a + [tagset_doc.id])
        elsif (completeness = Completeness.find(params[:tagset_id]))
          completeness.tagset.update(tagset_ids: completeness.tagset.tagset_ids.to_a + [tagset_doc.id])
          completeness.update(object_ids: completeness.object_ids.to_a + [tagset_doc.id])
        end
        if (new_state = tagset_doc.cycle.states.find_by(key: :share))
          tagset_doc.update(state: new_state)
        end
      end

      flash.now[:notice] = 'Documents ajouté'
      render turbo_stream: [
        turbo_stream.prepend(:flash_messages, partial: 'spirit_hub/common/flash_messages')
      ]
    end

    private

    def default_columns
      {
        type: { label: 'Type', sortable: true },
        cleaned_main_key: { label: 'Libellé', sortable: true },
        doc_file_size: { label: 'Poids', sortable: true },
        updated_at: { label: 'Dernière modification', sortable: true },
        last_current_user_name: { label: 'Provenance', sortable: true },
        informed: { label: 'Partagé', sortable: false },
        current_state: { label: 'Statut', sortable: true }
      }.freeze
    end

    def find_models
      scope = Tagset.where(:parent_tagset_ids.in => [nil, []], type: 'document', responsible: @user.id)
      @models = find_models_page(scope, default_sort_by: 'cleaned_main_key')
    end
  end
end
